@@ -40,7 +40,7 @@ class ReadMany(BaseModel):
     object  : ObjectName
     fields_ : Fields4 = Field(..., alias="fields")
     filter  : Optional[Filter]
-    order   : Optional[Order]
+    order   : Optional[Order] = [("DESC", ["id"])]
     page    : Optional[PositiveInt] = 1
     size    : Optional[PositiveInt] = 1000
 
